==> ejc-assistrmat-impl-3.0.0-20220914.081818-190-sources.jar: com/ejianc/business/outrmat/order/service/impl/OutRmatOrderDetailServiceImpl.java <==
package com.ejianc.business.outrmat.order.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.outrmat.order.bean.OutRmatOrderDetailEntity;
import com.ejianc.business.outrmat.order.mapper.OutRmatOrderDetailMapper;
import com.ejianc.business.outrmat.order.service.IOutRmatOrderDetailService;
import com.ejianc.business.outrmat.order.vo.OutRmatOrderDetailVO;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
@Service("outRmatOrderDetailService")
public class OutRmatOrderDetailServiceImpl extends BaseServiceImpl<OutRmatOrderDetailMapper, OutRmatOrderDetailEntity> implements IOutRmatOrderDetailService {

    @Override
    public Boolean deleteOrderDetailByOrderId(Long orderId) {
        return baseMapper.deleteOrderDetailByOrderId(orderId);
    }

    @Override
    public List<OutRmatOrderDetailVO> geOutRmatOrderDetail(QueryWrapper queryWrapper, Long contractId) {
        if(null==contractId){
            return new ArrayList<>();
        }
        return baseMapper.geOutRmatOrderDetail(queryWrapper,contractId);
    }
    @Override
    public List<OutRmatOrderDetailEntity> queryMaterialDetail(Long contractId,Long materialId,
                                                            Long unitId,Long unitMId,
                                                            String rentCalculationType) {
        return baseMapper.queryMaterialDetail(contractId,materialId,unitId,unitMId, rentCalculationType);
    }
}

==> ejc-assistrmat-impl-3.0.0-20220915.085559-210-sources.jar: com/ejianc/business/outrmat/order/service/impl/OutRmatOrderDetailServiceImpl.java <==
package com.ejianc.business.outrmat.order.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.outrmat.order.bean.OutRmatOrderDetailEntity;
import com.ejianc.business.outrmat.order.mapper.OutRmatOrderDetailMapper;
import com.ejianc.business.outrmat.order.service.IOutRmatOrderDetailService;
import com.ejianc.business.outrmat.order.vo.OutRmatOrderDetailVO;
import com.ejianc.business.outrmat.order.vo.OutRmatOrderVO;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
@Service("outRmatOrderDetailService")
public class OutRmatOrderDetailServiceImpl extends BaseServiceImpl<OutRmatOrderDetailMapper, OutRmatOrderDetailEntity> implements IOutRmatOrderDetailService {

    @Override
    public Boolean deleteOrderDetailByOrderId(Long orderId) {
        return baseMapper.deleteOrderDetailByOrderId(orderId);
    }

    @Override
    public List<OutRmatOrderDetailVO> geOutRmatOrderDetail(QueryWrapper queryWrapper, Long contractId) {
        if(null==contractId){
            return new ArrayList<>();
        }
        return baseMapper.geOutRmatOrderDetail(queryWrapper,contractId);
    }
    @Override
    public List<OutRmatOrderDetailEntity> queryMaterialDetail(Long contractId,Long materialId,
                                                            Long unitId,Long unitMId,
                                                            String rentCalculationType) {
        return baseMapper.queryMaterialDetail(contractId,materialId,unitId,unitMId, rentCalculationType);
    }

    @Override
    public List<OutRmatOrderVO> queryOrderNumTotal(List<Long> orderIdList) {
        if(CollectionUtils.isNotEmpty(orderIdList)){
            return new ArrayList<>();
        }
        return baseMapper.queryOrderNumTotal(orderIdList);
    }
}
